@@ -7,9 +7,13 @@ try:
     from watchdog.observers import Observer
     from watchdog.events import FileSystemEventHandler
 except ImportError:
+
     def ModuleChangedEventHandler(*args):
         return None
+
+
 else:
+
     class ModuleChangedEventHandler(FileSystemEventHandler):
         def __init__(self, paths, on_change):
             self.dirs = defaultdict(set)
@@ -33,7 +37,7 @@ else:
             path = os.path.abspath(path)
             for suff in importcompletion.SUFFIXES:
                 if path.endswith(suff):
-                    path = path[:-len(suff)]
+                    path = path[: -len(suff)]
                     break
             dirname = os.path.dirname(path)
             if dirname not in self.dirs:
@@ -54,7 +58,7 @@ else:
 
         def activate(self):
             if self.activated:
-                raise ValueError("%r is already activated." % (self,))
+                raise ValueError(f"{self!r} is already activated.")
             if not self.started:
                 self.started = True
                 self.observer.start()
@@ -67,12 +71,12 @@ else:
 
         def deactivate(self):
             if not self.activated:
-                raise ValueError("%r is not activated." % (self,))
+                raise ValueError(f"{self!r} is not activated.")
             self.observer.unschedule_all()
             self.activated = False
 
         def on_any_event(self, event):
             dirpath = os.path.dirname(event.src_path)
-            paths = [path + '.py' for path in self.dirs[dirpath]]
+            paths = [path + ".py" for path in self.dirs[dirpath]]
             if event.src_path in paths:
                 self.on_change(files_modified=[event.src_path])
