@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 # The MIT License
 #
 # Copyright (c) 2009-2011 the bpython authors.
@@ -23,11 +21,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from __future__ import absolute_import
-
 import code
 import inspect
-import io
 import os
 import pkgutil
 import pydoc
@@ -38,15 +33,14 @@ import tempfile
 import textwrap
 import time
 import traceback
+from enum import Enum
 from itertools import takewhile
-from six import itervalues
+from pathlib import Path
 from types import ModuleType
 
 from pygments.token import Token
-
-from . import autocomplete
-from . import inspection
-from ._py3compat import PythonLexer, py3, prepare_for_exec
+from pygments.lexers import Python3Lexer
+from . import autocomplete, inspection, simpleeval
 from .clipboard import get_clipboard, CopyFailed
 from .config import getpreferredencoding
 from .formatter import Parenthesis
@@ -55,10 +49,10 @@ from .lazyre import LazyReCompile
 from .paste import PasteHelper, PastePinnwand, PasteFailed
 from .patch_linecache import filename_for_console_input
 from .translations import _, ngettext
-from . import simpleeval
+from .importcompletion import ModuleGatherer
 
 
-class RuntimeTimer(object):
+class RuntimeTimer:
     """Calculate running time"""
 
     def __init__(self):
@@ -81,7 +75,7 @@ class RuntimeTimer(object):
         return self.running_time - self.last_command
 
 
-class Interpreter(code.InteractiveInterpreter, object):
+class Interpreter(code.InteractiveInterpreter):
     """Source code interpreter for use in bpython."""
 
     bpython_input_re = LazyReCompile(r"<bpython-input-\d+>")
@@ -116,9 +110,7 @@ class Interpreter(code.InteractiveInterpreter, object):
             sys.modules["__main__"] = main_mod = ModuleType("__main__")
             locals = main_mod.__dict__
 
-        # Unfortunately code.InteractiveInterpreter is a classic class, so no
-        # super()
-        code.InteractiveInterpreter.__init__(self, locals)
+        super().__init__(locals)
         self.timer = RuntimeTimer()
 
     def reset_running_time(self):
@@ -136,43 +128,18 @@ class Interpreter(code.InteractiveInterpreter, object):
         files should always already have an encoding comment or be ASCII.
         By default an encoding line will be added if no filename is given.
 
-        In Python 3, source must be a unicode string
-        In Python 2, source may be latin-1 bytestring or unicode string,
-        following the interface of code.InteractiveInterpreter.
+        source must be a string
 
         Because adding an encoding comment to a unicode string in Python 2
         would cause a syntax error to be thrown which would reference code
         the user did not write, setting encoding to True when source is a
         unicode string in Python 2 will throw a ValueError."""
-        # str means bytestring in Py2
-        if encode and not py3 and isinstance(source, unicode):
-            if encode != "auto":
-                raise ValueError("can't add encoding line to unicode input")
-            encode = False
         if encode and filename is not None:
             # files have encoding comments or implicit encoding of ASCII
             if encode != "auto":
                 raise ValueError("shouldn't add encoding line to file contents")
             encode = False
 
-        if encode and not py3 and isinstance(source, str):
-            # encoding makes sense for bytestrings, so long as there
-            # isn't already an encoding comment
-            comment = inspection.get_encoding_comment(source)
-            if comment:
-                # keep the existing encoding comment, but add two lines
-                # because this interp always adds 2 to stack trace line
-                # numbers in Python 2
-                source = source.replace(comment, b"%s\n\n" % comment, 1)
-            else:
-                source = b"# coding: %s\n\n%s" % (self.encoding, source)
-        elif not py3 and filename is None:
-            # 2 blank lines still need to be added
-            # because this interpreter always adds 2 to stack trace line
-            # numbers in Python 2 when the filename is "<input>"
-            newlines = u"\n\n" if isinstance(source, unicode) else b"\n\n"
-            source = newlines + source
-            # we know we're in Python 2 here, so ok to reference unicode
         if filename is None:
             filename = filename_for_console_input(source)
         with self.timer:
@@ -202,8 +169,6 @@ class Interpreter(code.InteractiveInterpreter, object):
                 # strip linecache line number
                 if self.bpython_input_re.match(filename):
                     filename = "<input>"
-                if filename == "<input>" and not py3:
-                    lineno -= 2
                 value = SyntaxError(msg, (filename, lineno, offset, line))
                 sys.last_value = value
         exc_formatted = traceback.format_exception_only(exc_type, value)
@@ -226,9 +191,6 @@ class Interpreter(code.InteractiveInterpreter, object):
                 if self.bpython_input_re.match(fname):
                     fname = "<input>"
                     tblist[i] = (fname, lineno, module, something)
-                # Set the right lineno (encoding header adds an extra line)
-                if fname == "<input>" and not py3:
-                    tblist[i] = (fname, lineno - 2, module, something)
 
             l = traceback.format_list(tblist)
             if l:
@@ -246,7 +208,7 @@ class Interpreter(code.InteractiveInterpreter, object):
             self.write(line)
 
 
-class MatchesIterator(object):
+class MatchesIterator:
     """Stores a list of matches and which one is currently selected if any.
 
     Also responsible for doing the actual replacement of the original line with
@@ -367,7 +329,7 @@ class MatchesIterator(object):
         self.index = -1
 
 
-class Interaction(object):
+class Interaction:
     def __init__(self, config, statusbar=None):
         self.config = config
 
@@ -388,17 +350,15 @@ class SourceNotFound(Exception):
     """Exception raised when the requested source could not be found."""
 
 
-class LineTypeTranslator(object):
-    """ Used when adding a tuple to all_logical_lines, to get input / output values
-    having to actually type/know the strings """
-
-    # TODO use Enum once we drop support for Python 2
+class LineTypeTranslator(Enum):
+    """Used when adding a tuple to all_logical_lines, to get input / output values
+    having to actually type/know the strings"""
 
     INPUT = "input"
     OUTPUT = "output"
 
 
-class Repl(object):
+class Repl:
     """Implements the necessary guff for a Python-repl-alike interface
 
     The execution of the code entered and all that stuff was taken from the
@@ -472,45 +432,41 @@ class Repl(object):
         self.closed = False
         self.clipboard = get_clipboard()
 
-        pythonhist = os.path.expanduser(self.config.hist_file)
-        if os.path.exists(pythonhist):
+        if self.config.hist_file.exists():
             try:
                 self.rl_history.load(
-                    pythonhist, getpreferredencoding() or "ascii"
+                    self.config.hist_file, getpreferredencoding() or "ascii"
                 )
-            except EnvironmentError:
+            except OSError:
                 pass
 
+        self.module_gatherer = ModuleGatherer(
+            skiplist=self.config.import_completion_skiplist
+        )
         self.completers = autocomplete.get_default_completer(
-            config.autocomplete_mode
+            config.autocomplete_mode, self.module_gatherer
         )
         if self.config.pastebin_helper:
             self.paster = PasteHelper(self.config.pastebin_helper)
         else:
             self.paster = PastePinnwand(
-                self.config.pastebin_url, self.config.pastebin_expiry,
+                self.config.pastebin_url,
+                self.config.pastebin_expiry,
             )
 
     @property
     def ps1(self):
         try:
-            if not py3:
-                return sys.ps1.decode(getpreferredencoding())
-            else:
-                return sys.ps1
+            return sys.ps1
         except AttributeError:
-            return u">>> "
+            return ">>> "
 
     @property
     def ps2(self):
         try:
-            if not py3:
-                return sys.ps2.decode(getpreferredencoding())
-            else:
-                return sys.ps2
-
+            return sys.ps2
         except AttributeError:
-            return u"... "
+            return "... "
 
     def startup(self):
         """
@@ -520,11 +476,8 @@ class Repl(object):
         filename = os.environ.get("PYTHONSTARTUP")
         if filename:
             encoding = inspection.get_encoding_file(filename)
-            with io.open(filename, "rt", encoding=encoding) as f:
+            with open(filename, encoding=encoding) as f:
                 source = f.read()
-                if not py3:
-                    # Early Python 2.7.X need bytes.
-                    source = source.encode(encoding)
                 self.interp.runsource(source, filename, "exec", encode=False)
 
     def current_string(self, concatenate=False):
@@ -575,7 +528,7 @@ class Repl(object):
         # argument so we're done counting
         stack = [["", "", 0, ""]]
         try:
-            for (token, value) in PythonLexer().get_tokens(line):
+            for (token, value) in Python3Lexer().get_tokens(line):
                 if token is Token.Punctuation:
                     if value in "([{":
                         stack.append(["", "", 0, value])
@@ -702,11 +655,11 @@ class Repl(object):
                     obj = self.get_object(line)
             return inspection.get_source_unicode(obj)
         except (AttributeError, NameError) as e:
-            msg = _(u"Cannot get source: %s") % (e,)
-        except IOError as e:
-            msg = u"%s" % (e,)
+            msg = _("Cannot get source: %s") % (e,)
+        except OSError as e:
+            msg = f"{e}"
         except TypeError as e:
-            if "built-in" in u"%s" % (e,):
+            if "built-in" in f"{e}":
                 msg = _("Cannot access source of %r") % (obj,)
             else:
                 msg = _("No source code found for %s") % (self.current_line,)
@@ -832,7 +785,7 @@ class Repl(object):
         i.e. without >>> and ... at input lines and with "# OUT: " prepended to
         output lines and "### " prepended to current line"""
 
-        if hasattr(self, 'all_logical_lines'):
+        if hasattr(self, "all_logical_lines"):
             # Curtsies
 
             def process():
@@ -850,13 +803,14 @@ class Repl(object):
 
             def process():
                 for line in session_output.split("\n"):
-                    if line.startswith(self.ps1):	
-                        yield line[len(self.ps1) :]	
-                    elif line.startswith(self.ps2):	
-                        yield line[len(self.ps2) :]	
-                    elif line.rstrip():	        
-                        yield "# OUT: %s" % (line,)
-            return '\n'.join(process())
+                    if line.startswith(self.ps1):
+                        yield line[len(self.ps1) :]
+                    elif line.startswith(self.ps2):
+                        yield line[len(self.ps2) :]
+                    elif line.rstrip():
+                        yield f"# OUT: {line}"
+
+            return "\n".join(process())
 
     def write2file(self):
         """Prompt for a filename and write the current contents of the stdout
@@ -871,13 +825,13 @@ class Repl(object):
             self.interact.notify(_("Save cancelled."))
             return
 
-        if fn.startswith("~"):
-            fn = os.path.expanduser(fn)
-        if not fn.endswith(".py") and self.config.save_append_py:
-            fn = fn + ".py"
+        fn = Path(fn).expanduser()
+        if fn.suffix != ".py" and self.config.save_append_py:
+            # fn.with_suffix(".py") does not append if fn has a non-empty suffix
+            fn = Path(f"{fn}.py")
 
         mode = "w"
-        if os.path.exists(fn):
+        if fn.exists():
             mode = self.interact.file_prompt(
                 _(
                     "%s already exists. Do you "
@@ -900,7 +854,7 @@ class Repl(object):
         try:
             with open(fn, mode) as f:
                 f.write(stdout_text)
-        except IOError as e:
+        except OSError as e:
             self.interact.notify(_("Error writing file '%s': %s") % (fn, e))
         else:
             self.interact.notify(_("Saved to %s.") % (fn,))
@@ -983,13 +937,12 @@ class Repl(object):
         return more
 
     def insert_into_history(self, s):
-        pythonhist = os.path.expanduser(self.config.hist_file)
         try:
             self.rl_history.append_reload_and_write(
-                s, pythonhist, getpreferredencoding()
+                s, self.config.hist_file, getpreferredencoding()
             )
         except RuntimeError as e:
-            self.interact.notify(u"%s" % (e,))
+            self.interact.notify(f"{e}")
 
     def prompt_undo(self):
         """Returns how many lines to undo, 0 means don't undo"""
@@ -1082,7 +1035,7 @@ class Repl(object):
         if self.cpos:
             cursor += 1
         stack = list()
-        all_tokens = list(PythonLexer().get_tokens(source))
+        all_tokens = list(Python3Lexer().get_tokens(source))
         # Unfortunately, Pygments adds a trailing newline and strings with
         # no size, so strip them
         while not all_tokens[-1][1]:
@@ -1116,7 +1069,7 @@ class Repl(object):
                         stack.append(
                             (line, len(line_tokens) - 1, line_tokens, value)
                         )
-                elif value in itervalues(parens):
+                elif value in parens.values():
                     saved_stack = list(stack)
                     try:
                         while True:
@@ -1171,33 +1124,25 @@ class Repl(object):
         exited with non-zero"""
 
         encoding = getpreferredencoding()
-        editor_args = shlex.split(
-            prepare_for_exec(self.config.editor, encoding)
-        )
+        editor_args = shlex.split(self.config.editor)
         with tempfile.NamedTemporaryFile(suffix=".py") as temp:
             temp.write(text.encode(encoding))
             temp.flush()
 
-            args = editor_args + [prepare_for_exec(temp.name, encoding)]
+            args = editor_args + [temp.name]
             if subprocess.call(args) == 0:
                 with open(temp.name) as f:
-                    if py3:
-                        return f.read()
-                    else:
-                        return f.read().decode(encoding)
+                    return f.read()
             else:
                 return text
 
     def open_in_external_editor(self, filename):
-        encoding = getpreferredencoding()
-        editor_args = shlex.split(
-            prepare_for_exec(self.config.editor, encoding)
-        )
-        args = editor_args + [prepare_for_exec(filename, encoding)]
+        editor_args = shlex.split(self.config.editor)
+        args = editor_args + [filename]
         return subprocess.call(args) == 0
 
     def edit_config(self):
-        if not os.path.isfile(self.config.config_path):
+        if not self.config.config_path.is_file():
             if self.interact.confirm(
                 _(
                     "Config file does not exist - create "
@@ -1208,19 +1153,17 @@ class Repl(object):
                     default_config = pkgutil.get_data(
                         "bpython", "sample-config"
                     )
-                    if py3:  # py3 files need unicode
-                        default_config = default_config.decode("ascii")
-                    containing_dir = os.path.dirname(
-                        os.path.abspath(self.config.config_path)
-                    )
-                    if not os.path.exists(containing_dir):
-                        os.makedirs(containing_dir)
+                    # Py3  files need unicode
+                    default_config = default_config.decode("ascii")
+                    containing_dir = self.config.config_path.parent
+                    if not containing_dir.exists():
+                        containing_dir.mkdir(parents=True)
                     with open(self.config.config_path, "w") as f:
                         f.write(default_config)
-                except (IOError, OSError) as e:
+                except OSError as e:
                     self.interact.notify(
                         _("Error writing file '%s': %s")
-                        % (self.config.config.path, e)
+                        % (self.config.config_path, e)
                     )
                     return False
             else:
@@ -1253,10 +1196,10 @@ def next_indentation(line, tab_length):
 def next_token_inside_string(code_string, inside_string):
     """Given a code string s and an initial state inside_string, return
     whether the next token will be inside a string or not."""
-    for token, value in PythonLexer().get_tokens(code_string):
+    for token, value in Python3Lexer().get_tokens(code_string):
         if token is Token.String:
             value = value.lstrip("bBrRuU")
-            if value in ['"""', "'''", '"', "'"]:
+            if value in ('"""', "'''", '"', "'"):
                 if not inside_string:
                     inside_string = value
                 elif value == inside_string:
