@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 import fcntl
 import os
 import pty
@@ -7,8 +5,10 @@ import struct
 import sys
 import termios
 import textwrap
+import unittest
 
-from bpython.test import unittest, TEST_CONFIG
+from bpython.test import TEST_CONFIG
+from bpython.config import getpreferredencoding
 
 try:
     from twisted.internet import reactor
@@ -16,31 +16,26 @@ try:
     from twisted.internet.protocol import ProcessProtocol
     from twisted.trial.unittest import TestCase as TrialTestCase
 except ImportError:
-    class TrialTestCase(object):
+
+    class TrialTestCase:
         pass
+
     reactor = None
 
 try:
     import urwid
+
     have_urwid = True
 except ImportError:
     have_urwid = False
 
-try:
-    from nose.plugins.attrib import attr
-except ImportError:
-    def attr(*args, **kwargs):
-        def identity(func):
-            return func
-        return identity
-
 
 def set_win_size(fd, rows, columns):
-    s = struct.pack('HHHH', rows, columns, 0, 0)
+    s = struct.pack("HHHH", rows, columns, 0, 0)
     fcntl.ioctl(fd, termios.TIOCSWINSZ, s)
 
 
-class CrashersTest(object):
+class CrashersTest:
     backend = "cli"
 
     def run_bpython(self, input):
@@ -52,6 +47,7 @@ class CrashersTest(object):
         Returns bpython's output.
         """
         result = Deferred()
+        encoding = getpreferredencoding()
 
         class Protocol(ProcessProtocol):
             STATES = (SEND_INPUT, COLLECT) = range(2)
@@ -63,7 +59,7 @@ class CrashersTest(object):
                 self.state = next(self.states)
 
             def outReceived(self, data):
-                self.data += data
+                self.data += data.decode(encoding)
                 if self.delayed_call is not None:
                     self.delayed_call.cancel()
                 self.delayed_call = reactor.callLater(0.5, self.next)
@@ -73,8 +69,8 @@ class CrashersTest(object):
                 if self.state == self.SEND_INPUT:
                     index = self.data.find(">>> ")
                     if index >= 0:
-                        self.data = self.data[index + 4:]
-                        self.transport.write(input)
+                        self.data = self.data[index + 4 :]
+                        self.transport.write(input.encode(encoding))
                         self.state = next(self.states)
                 else:
                     self.transport.closeStdin()
@@ -90,32 +86,42 @@ class CrashersTest(object):
         (master, slave) = pty.openpty()
         set_win_size(slave, 25, 80)
         reactor.spawnProcess(
-            Protocol(), sys.executable,
-            (sys.executable, "-m", "bpython." + self.backend, "--config",
-             TEST_CONFIG),
-            env=dict(TERM="vt100", LANG=os.environ.get("LANG", "")),
-            usePTY=(master, slave, os.ttyname(slave)))
+            Protocol(),
+            sys.executable,
+            (
+                sys.executable,
+                "-m",
+                f"bpython.{self.backend}",
+                "--config",
+                str(TEST_CONFIG),
+            ),
+            env={
+                "TERM": "vt100",
+                "LANG": os.environ.get("LANG", "C.UTF-8"),
+            },
+            usePTY=(master, slave, os.ttyname(slave)),
+        )
         return result
 
-    @attr(speed='slow')
     def test_issue108(self):
         input = textwrap.dedent(
             """\
             def spam():
             u"y\\xe4y"
             \b
-            spam(""")
+            spam("""
+        )
         deferred = self.run_bpython(input)
         return deferred.addCallback(self.check_no_traceback)
 
-    @attr(speed='slow')
     def test_issue133(self):
         input = textwrap.dedent(
             """\
             def spam(a, (b, c)):
             pass
             \b
-            spam(1""")
+            spam(1"""
+        )
         return self.run_bpython(input).addCallback(self.check_no_traceback)
 
     def check_no_traceback(self, data):
