@@ -1,14 +1,13 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import code
 import os
 import sys
 import tempfile
 import io
-from functools import partial
+import unittest
+
 from contextlib import contextmanager
-from six.moves import StringIO
+from functools import partial
+from unittest import mock
 
 from bpython.curtsiesfrontend import repl as curtsiesrepl
 from bpython.curtsiesfrontend import interpreter
@@ -17,23 +16,14 @@ from bpython.repl import LineTypeTranslator as LineType
 from bpython import autocomplete
 from bpython import config
 from bpython import args
-from bpython._py3compat import py3
 from bpython.test import (
     FixLanguageTestCase as TestCase,
     MagicIterMock,
-    mock,
-    unittest,
     TEST_CONFIG,
 )
 
 from curtsies import events
-
-if py3:
-    from importlib import invalidate_caches
-else:
-
-    def invalidate_caches():
-        """Does not exist before Python 3.3"""
+from importlib import invalidate_caches
 
 
 def setup_config(conf):
@@ -41,7 +31,7 @@ def setup_config(conf):
     config.loadini(config_struct, TEST_CONFIG)
     for key, value in conf.items():
         if not hasattr(config_struct, key):
-            raise ValueError("%r is not a valid config attribute" % (key,))
+            raise ValueError(f"{key!r} is not a valid config attribute")
         setattr(config_struct, key, value)
     return config_struct
 
@@ -113,10 +103,7 @@ class TestCurtsiesRepl(TestCase):
 
 
 def mock_next(obj, return_value):
-    if py3:
-        obj.__next__.return_value = return_value
-    else:
-        obj.next.return_value = return_value
+    obj.__next__.return_value = return_value
 
 
 class TestCurtsiesReplTab(TestCase):
@@ -235,7 +222,7 @@ class TestCurtsiesReplFilenameCompletion(TestCase):
 # from http://stackoverflow.com/a/17981937/398212 - thanks @rkennedy
 @contextmanager
 def captured_output():
-    new_out, new_err = StringIO(), StringIO()
+    new_out, new_err = io.StringIO(), io.StringIO()
     old_out, old_err = sys.stdout, sys.stderr
     try:
         sys.stdout, sys.stderr = new_out, new_err
@@ -246,7 +233,7 @@ def captured_output():
 
 def create_repl(**kwargs):
     config = setup_config({"editor": "true"})
-    repl = curtsiesrepl.BaseRepl(config=config, **kwargs)
+    repl = curtsiesrepl.BaseRepl(config, **kwargs)
     os.environ["PAGER"] = "true"
     os.environ.pop("PYTHONSTARTUP", None)
     repl.width = 50
@@ -258,7 +245,6 @@ class TestFutureImports(TestCase):
     def test_repl(self):
         repl = create_repl()
         with captured_output() as (out, err):
-            repl.push("from __future__ import division")
             repl.push("1 / 2")
         self.assertEqual(out.getvalue(), "0.5\n")
 
@@ -266,7 +252,6 @@ class TestFutureImports(TestCase):
         interp = code.InteractiveInterpreter(locals={})
         with captured_output() as (out, err):
             with tempfile.NamedTemporaryFile(mode="w", suffix=".py") as f:
-                f.write("from __future__ import division\n")
                 f.write("print(1/2)\n")
                 f.flush()
                 args.exec_code(interp, [f.name])
@@ -421,7 +406,7 @@ class TestCurtsiesPagerText(TestCase):
         self.repl.pager = self.assert_pager_gets_unicode
 
     def assert_pager_gets_unicode(self, text):
-        self.assertIsInstance(text, type(""))
+        self.assertIsInstance(text, str)
 
     def test_help(self):
         self.repl.pager(self.repl.help_text())
@@ -448,11 +433,10 @@ class TestCurtsiesStartup(TestCase):
         self.repl = create_repl()
 
     def write_startup_file(self, fname, encoding):
-        with io.open(fname, mode="wt", encoding=encoding) as f:
+        with open(fname, mode="wt", encoding=encoding) as f:
             f.write("# coding: ")
             f.write(encoding)
             f.write("\n")
-            f.write("from __future__ import unicode_literals\n")
             f.write('a = "äöü"\n')
 
     def test_startup_event_utf8(self):
