@@ -1,41 +1,29 @@
-# -*- coding: utf-8 -*-
-
 import os
+import unittest
 
-from bpython._py3compat import py3
 from bpython import inspection
-from bpython.test import unittest
 from bpython.test.fodder import encoding_ascii
 from bpython.test.fodder import encoding_latin1
 from bpython.test.fodder import encoding_utf8
 
 
-foo_ascii_only = u'''def foo():
+foo_ascii_only = '''def foo():
     """Test"""
     pass
 '''
 
-foo_non_ascii = u'''def foo():
+foo_non_ascii = '''def foo():
     """Test äöü"""
     pass
 '''
 
 
-class OldCallable:
+class Callable:
     def __call__(self):
         pass
 
 
-class Callable(object):
-    def __call__(self):
-        pass
-
-
-class OldNoncallable:
-    pass
-
-
-class Noncallable(object):
+class Noncallable:
     pass
 
 
@@ -43,41 +31,12 @@ def spam():
     pass
 
 
-class CallableMethod(object):
+class CallableMethod:
     def method(self):
         pass
 
 
 class TestInspection(unittest.TestCase):
-    def test_is_callable(self):
-        self.assertTrue(inspection.is_callable(spam))
-        self.assertTrue(inspection.is_callable(Callable))
-        self.assertTrue(inspection.is_callable(Callable()))
-        self.assertTrue(inspection.is_callable(OldCallable))
-        self.assertTrue(inspection.is_callable(OldCallable()))
-        self.assertFalse(inspection.is_callable(Noncallable()))
-        self.assertFalse(inspection.is_callable(OldNoncallable()))
-        self.assertFalse(inspection.is_callable(None))
-        self.assertTrue(inspection.is_callable(CallableMethod().method))
-
-    @unittest.skipIf(py3, "old-style classes only exist in Python 2")
-    def test_is_new_style_py2(self):
-        self.assertTrue(inspection.is_new_style(spam))
-        self.assertTrue(inspection.is_new_style(Noncallable))
-        self.assertFalse(inspection.is_new_style(OldNoncallable))
-        self.assertTrue(inspection.is_new_style(Noncallable()))
-        self.assertFalse(inspection.is_new_style(OldNoncallable()))
-        self.assertTrue(inspection.is_new_style(None))
-
-    @unittest.skipUnless(py3, "only in Python 3 are all classes new-style")
-    def test_is_new_style_py3(self):
-        self.assertTrue(inspection.is_new_style(spam))
-        self.assertTrue(inspection.is_new_style(Noncallable))
-        self.assertTrue(inspection.is_new_style(OldNoncallable))
-        self.assertTrue(inspection.is_new_style(Noncallable()))
-        self.assertTrue(inspection.is_new_style(OldNoncallable()))
-        self.assertTrue(inspection.is_new_style(None))
-
     def test_parsekeywordpairs(self):
         # See issue #109
         def fails(spam=["-a", "-b"]):
@@ -155,7 +114,7 @@ class TestInspection(unittest.TestCase):
         self.assertEqual(encoding, "utf-8")
 
 
-class A(object):
+class A:
     a = "a"
 
 
@@ -163,21 +122,15 @@ class B(A):
     b = "b"
 
 
-class Property(object):
+class Property:
     @property
     def prop(self):
         raise AssertionError("Property __get__ executed")
 
 
-class Slots(object):
+class Slots:
     __slots__ = ["s1", "s2", "s3"]
 
-    if not py3:
-
-        @property
-        def s3(self):
-            raise AssertionError("Property __get__ executed")
-
 
 class SlotsSubclass(Slots):
     @property
@@ -185,21 +138,21 @@ class SlotsSubclass(Slots):
         raise AssertionError("Property __get__ executed")
 
 
-class OverriddenGetattr(object):
+class OverriddenGetattr:
     def __getattr__(self, attr):
         raise AssertionError("custom __getattr__ executed")
 
     a = 1
 
 
-class OverriddenGetattribute(object):
+class OverriddenGetattribute:
     def __getattribute__(self, attr):
         raise AssertionError("custom __getattribute__ executed")
 
     a = 1
 
 
-class OverriddenMRO(object):
+class OverriddenMRO:
     def __mro__(self):
         raise AssertionError("custom mro executed")
 
@@ -250,14 +203,6 @@ class TestSafeGetAttribute(unittest.TestCase):
         self.assertEqual(inspection.hasattr_safe(s, "s1"), False)
         self.assertEqual(inspection.hasattr_safe(s, "s4"), True)
 
-    @unittest.skipIf(py3, "Py 3 doesn't allow slots and prop in same class")
-    def test_lookup_with_property_and_slots(self):
-        sga = inspection.getattr_safe
-        s = SlotsSubclass()
-        self.assertIsInstance(sga(Slots, "s3"), property)
-        self.assertEqual(inspection.getattr_safe(s, "s3"), Slots.__dict__["s3"])
-        self.assertIsInstance(sga(SlotsSubclass, "s3"), property)
-
     def test_lookup_on_overridden_methods(self):
         sga = inspection.getattr_safe
         self.assertEqual(sga(OverriddenGetattr(), "a"), 1)
