@@ -1,8 +1,6 @@
-# encoding: utf-8
-
 import re
+import unittest
 
-from bpython.test import unittest
 from bpython.line import (
     current_word,
     current_dict_key,
