@@ -1,19 +1,17 @@
-# encoding: utf-8
-
-from itertools import islice
-from six.moves import range
 import collections
 import inspect
-import os
-import shutil
 import socket
 import sys
 import tempfile
+import unittest
+
+from itertools import islice
+from pathlib import Path
+from unittest import mock
 
-from bpython._py3compat import py3
 from bpython import config, repl, cli, autocomplete
-from bpython.test import MagicIterMock, mock, FixLanguageTestCase as TestCase
-from bpython.test import unittest, TEST_CONFIG
+from bpython.test import MagicIterMock, FixLanguageTestCase as TestCase
+from bpython.test import TEST_CONFIG
 
 
 pypy = "PyPy" in sys.version
@@ -331,15 +329,11 @@ class TestEditConfig(TestCase):
         self.repl.config.editor = "true"
 
     def test_create_config(self):
-        tmp_dir = tempfile.mkdtemp()
-        try:
-            config_path = os.path.join(tmp_dir, "newdir", "config")
+        with tempfile.TemporaryDirectory() as tmp_dir:
+            config_path = Path(tmp_dir) / "newdir" / "config"
             self.repl.config.config_path = config_path
             self.repl.edit_config()
-            self.assertTrue(os.path.exists(config_path))
-        finally:
-            shutil.rmtree(tmp_dir)
-            self.assertFalse(os.path.exists(config_path))
+            self.assertTrue(config_path.exists())
 
 
 class TestRepl(unittest.TestCase):
@@ -368,7 +362,9 @@ class TestRepl(unittest.TestCase):
     # COMPLETE TESTS
     # 1. Global tests
     def test_simple_global_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SIMPLE})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SIMPLE}
+        )
         self.set_input_line("d")
 
         self.assertTrue(self.repl.complete())
@@ -379,7 +375,9 @@ class TestRepl(unittest.TestCase):
         )
 
     def test_substring_global_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SUBSTRING})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SUBSTRING}
+        )
         self.set_input_line("time")
 
         self.assertTrue(self.repl.complete())
@@ -389,21 +387,23 @@ class TestRepl(unittest.TestCase):
         )
 
     def test_fuzzy_global_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.FUZZY})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.FUZZY}
+        )
         self.set_input_line("doc")
 
         self.assertTrue(self.repl.complete())
         self.assertTrue(hasattr(self.repl.matches_iter, "matches"))
         self.assertEqual(
             self.repl.matches_iter.matches,
-            ["UnboundLocalError(", "__doc__"]
-            if not py3
-            else ["ChildProcessError(", "UnboundLocalError(", "__doc__"],
+            ["ChildProcessError(", "UnboundLocalError(", "__doc__"],
         )
 
     # 2. Attribute tests
     def test_simple_attribute_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SIMPLE})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SIMPLE}
+        )
         self.set_input_line("Foo.b")
 
         code = "class Foo():\n\tdef bar(self):\n\t\tpass\n"
@@ -415,7 +415,9 @@ class TestRepl(unittest.TestCase):
         self.assertEqual(self.repl.matches_iter.matches, ["Foo.bar"])
 
     def test_substring_attribute_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SUBSTRING})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SUBSTRING}
+        )
         self.set_input_line("Foo.az")
 
         code = "class Foo():\n\tdef baz(self):\n\t\tpass\n"
@@ -427,7 +429,9 @@ class TestRepl(unittest.TestCase):
         self.assertEqual(self.repl.matches_iter.matches, ["Foo.baz"])
 
     def test_fuzzy_attribute_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.FUZZY})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.FUZZY}
+        )
         self.set_input_line("Foo.br")
 
         code = "class Foo():\n\tdef bar(self):\n\t\tpass\n"
@@ -440,7 +444,9 @@ class TestRepl(unittest.TestCase):
 
     # 3. Edge cases
     def test_updating_namespace_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SIMPLE})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SIMPLE}
+        )
         self.set_input_line("foo")
         self.repl.push("foobar = 2")
 
@@ -449,7 +455,9 @@ class TestRepl(unittest.TestCase):
         self.assertEqual(self.repl.matches_iter.matches, ["foobar"])
 
     def test_file_should_not_appear_in_complete(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SIMPLE})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SIMPLE}
+        )
         self.set_input_line("_")
         self.assertTrue(self.repl.complete())
         self.assertTrue(hasattr(self.repl.matches_iter, "matches"))
@@ -457,7 +465,9 @@ class TestRepl(unittest.TestCase):
 
     # 4. Parameter names
     def test_paremeter_name_completion(self):
-        self.repl = FakeRepl({"autocomplete_mode": autocomplete.SIMPLE})
+        self.repl = FakeRepl(
+            {"autocomplete_mode": autocomplete.AutocompleteModes.SIMPLE}
+        )
         self.set_input_line("foo(ab")
 
         code = "def foo(abc=1, abd=2, xyz=3):\n\tpass\n"
@@ -503,10 +513,7 @@ class TestCliReplTab(unittest.TestCase):
     # 3 Types of tab complete
     def test_simple_tab_complete(self):
         self.repl.matches_iter = MagicIterMock()
-        if py3:
-            self.repl.matches_iter.__bool__.return_value = False
-        else:
-            self.repl.matches_iter.__nonzero__.return_value = False
+        self.repl.matches_iter.__bool__.return_value = False
         self.repl.complete = mock.Mock()
         self.repl.print_line = mock.Mock()
         self.repl.matches_iter.is_cseq.return_value = False
@@ -524,7 +531,9 @@ class TestCliReplTab(unittest.TestCase):
     @unittest.skip("disabled while non-simple completion is disabled")
     def test_substring_tab_complete(self):
         self.repl.s = "bar"
-        self.repl.config.autocomplete_mode = autocomplete.FUZZY
+        self.repl.config.autocomplete_mode = (
+            autocomplete.AutocompleteModes.FUZZY
+        )
         self.repl.tab()
         self.assertEqual(self.repl.s, "foobar")
         self.repl.tab()
@@ -533,14 +542,16 @@ class TestCliReplTab(unittest.TestCase):
     @unittest.skip("disabled while non-simple completion is disabled")
     def test_fuzzy_tab_complete(self):
         self.repl.s = "br"
-        self.repl.config.autocomplete_mode = autocomplete.FUZZY
+        self.repl.config.autocomplete_mode = (
+            autocomplete.AutocompleteModes.FUZZY
+        )
         self.repl.tab()
         self.assertEqual(self.repl.s, "foobar")
 
     # Edge Cases
     def test_normal_tab(self):
         """make sure pressing the tab key will
-           still in some cases add a tab"""
+        still in some cases add a tab"""
         self.repl.s = ""
         self.repl.config = mock.Mock()
         self.repl.config.tab_length = 4
@@ -570,7 +581,9 @@ class TestCliReplTab(unittest.TestCase):
     def test_fuzzy_attribute_tab_complete(self):
         """Test fuzzy attribute with no text"""
         self.repl.s = "Foo."
-        self.repl.config.autocomplete_mode = autocomplete.FUZZY
+        self.repl.config.autocomplete_mode = (
+            autocomplete.AutocompleteModes.FUZZY
+        )
 
         self.repl.tab()
         self.assertEqual(self.repl.s, "Foo.foobar")
@@ -579,7 +592,9 @@ class TestCliReplTab(unittest.TestCase):
     def test_fuzzy_attribute_tab_complete2(self):
         """Test fuzzy attribute with some text"""
         self.repl.s = "Foo.br"
-        self.repl.config.autocomplete_mode = autocomplete.FUZZY
+        self.repl.config.autocomplete_mode = (
+            autocomplete.AutocompleteModes.FUZZY
+        )
 
         self.repl.tab()
         self.assertEqual(self.repl.s, "Foo.foobar")
@@ -597,7 +612,9 @@ class TestCliReplTab(unittest.TestCase):
 
     @unittest.skip("disabled while non-simple completion is disabled")
     def test_substring_expand_forward(self):
-        self.repl.config.autocomplete_mode = autocomplete.SUBSTRING
+        self.repl.config.autocomplete_mode = (
+            autocomplete.AutocompleteModes.SUBSTRING
+        )
         self.repl.s = "ba"
         self.repl.tab()
         self.assertEqual(self.repl.s, "bar")
