@@ -1,33 +1,19 @@
-# encoding: utf-8
-
-from __future__ import absolute_import
-
 import gettext
 import locale
 import os.path
 import sys
 
 from .. import package_dir
-from .._py3compat import py3
 
 translator = None
 
-if py3:
 
-    def _(message):
-        return translator.gettext(message)
-
-    def ngettext(singular, plural, n):
-        return translator.ngettext(singular, plural, n)
+def _(message):
+    return translator.gettext(message)
 
 
-else:
-
-    def _(message):
-        return translator.ugettext(message)
-
-    def ngettext(singular, plural, n):
-        return translator.ungettext(singular, plural, n)
+def ngettext(singular, plural, n):
+    return translator.ngettext(singular, plural, n)
 
 
 def init(locale_dir=None, languages=None):
